@@ -7,6 +7,7 @@ import json
 from io import StringIO
 from nbpdfexport import notebook_to_pdf
 import asyncio
+from .asyncio_patch import monkeypatch, run_nested_until_complete
 
 
 def export_to_pdf(notebook, pdf_name):
@@ -24,8 +25,9 @@ def export_to_pdf(notebook, pdf_name):
 
     notebook_model = nbformat.read(StringIO(json.dumps(notebook)), as_version = version)
 
-    try:
-        __IPYTHON__
-        asyncio.ensure_future(notebook_to_pdf(notebook_model, pdf_name))
-    except NameError:
-        asyncio.get_event_loop().run_until_complete(notebook_to_pdf(notebook_model, pdf_name))
+    # try:
+    #     __IPYTHON__
+    #     asyncio.ensure_future(notebook_to_pdf(notebook_model, pdf_name))
+    # except NameError:
+    #     asyncio.get_event_loop().run_until_complete(notebook_to_pdf(notebook_model, pdf_name))
+    run_nested_until_complete(notebook_to_pdf(notebook_model, pdf_name))
